==> haskell-implicit-hie-0.1.4.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-JkgVPnIYTt39Myb27VJbWg
key:                  implicit-hie-0.1.4.0-JkgVPnIYTt39Myb27VJbWg
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  5dd16ac460518f79f6f0324c28a0aec9
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-JkgVPnIYTt39Myb27VJbWg
depends:
    attoparsec-0.14.4-99Ep8AgC5YbKR8GAd3oR9D base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-FwZ2QbvvsVvFCN1F2aHZPk text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-31hmY8yatXJDt4GSriZBBL

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.4.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-3bNtFmyPFT0DoQRaunkcJ3
key:                  implicit-hie-0.1.4.0-3bNtFmyPFT0DoQRaunkcJ3
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  05c1b9ab174db5d0339105b3e755faa3
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-3bNtFmyPFT0DoQRaunkcJ3
depends:
    attoparsec-0.14.4-263Fn5MXyjqGBhD6CjKCLb base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-bvrWNl6aSk4vNfT1PzspU text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-fHVyAj12mF6BeJWlDmLdf

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
